@@ -2,159 +2,25 @@
 #'
 #' `bayesian()` is a way to generate a _specification_ of a model
 #'  before fitting and allows the model to be created using
-#'  \pkg{Stan} via \pkg{brms} package in R. The main
-#'  arguments for the model are:
-#' \itemize{
-#'   \item \code{prior} One or more \code{brmsprior} objects created by
-#'   \code{\link[brms]{set_prior}} or related functions and combined using
-#'   the \code{c} method or the \code{+} operator. See also
-#'   \code{\link[brms]{get_prior}} for more help.
-#'   \item \code{inits} Either \code{"random"} or \code{"0"}. If inits is
-#'   \code{"random"} (the default), \pkg{Stan} will randomly generate initial
-#'   values for parameters. If it is \code{"0"}, all parameters are initialized
-#'   to zero. This option is sometimes useful for certain families, as it happens
-#'   that default (\code{"random"}) inits cause samples to be essentially
-#'   constant. Generally, setting \code{inits = "0"} is worth a try, if chains
-#'   do not behave well. Alternatively, \code{inits} can be a list of lists
-#'   containing the initial values, or a function (or function name) generating
-#'   initial values. The latter options are mainly implemented for internal
-#'   testing but are available to users if necessary. If specifying initial
-#'   values using a list or a function then currently the parameter names must
-#'   correspond to the names used in the generated \pkg{Stan} code (not the names
-#'   used in \R). For more details on specifying initial values you can consult
-#'   the documentation of the selected \code{backend}.
-#'   \item \code{chains} Number of Markov chains (defaults to 4).
-#'   \item \code{iter} Number of total iterations per chain (including warmup;
-#'   defaults to 2000).
-#'   \item \code{warmup} A positive integer specifying number of warmup
-#'   (aka burnin) iterations. This also specifies the number of iterations
-#'   used for stepsize adaptation, so warmup samples should not be used for
-#'   inference. The number of warmup should not be larger than \code{iter}
-#'   and the default is \code{iter/2}.
-#'   \item \code{thin} Thinning rate. Must be a positive integer. Set
-#'   \code{thin > 1} to save memory and computation time if \code{iter} is
-#'   large.
-#'   \item \code{cores} Number of cores to use when executing the chains in
-#'   parallel, which defaults to 1 but we recommend setting the \code{mc.cores}
-#'   option to be as many processors as the hardware and RAM allow (up to the
-#'   number of chains). For non-Windows OS in non-interactive \R sessions,
-#'   forking is used instead of PSOCK clusters.
-#'   \item \code{algorithm} Character string naming the estimation approach
-#'   to use. Options are \code{"sampling"} for MCMC (the default),
-#'   \code{"meanfield"} for variational inference with independent normal
-#'   distributions, \code{"fullrank"} for variational inference with
-#'   a multivariate normal distribution, or \code{"fixed_param"} for sampling
-#'   from fixed parameter values. Can be set globally for the current \R session
-#'   via the \code{"brms.algorithm"} option (see \code{\link{options}}).
-#'   \item \code{backend} Character string naming the package to use as the
-#'   backend for fitting the \pkg{Stan} model. Options are \code{"rstan"} (the
-#'   default) or \code{"cmdstanr"}. Can be set globally for the current \R
-#'   session via the \code{"brms.backend"} option (see \code{\link{options}}).
-#'   Details on the \pkg{rstan} and \pkg{cmdstanr} packages are available at
-#'   \url{https://mc-stan.org/rstan/} and \url{https://mc-stan.org/cmdstanr/},
-#'   respectively.
-#'   \item \code{control} A named \code{list} of parameters to control the
-#'   sampler's behavior. It defaults to \code{NULL} so all the default values
-#'   are used.
-#'   The most important control parameters are discussed in the 'Details'
-#'   section below. For a comprehensive overview see
-#'   \code{\link[rstan]{stan}}.
-#'   \item \code{future} Logical; If \code{TRUE}, the
-#'   \pkg{\link[future]{future}} package is used for parallel execution of
-#'   the chains and argument \code{cores} will be ignored. Can be set
-#'   globally for the current \R session via the \code{future} option.
-#'   The execution type is controlled via \code{\link[future]{plan}}
-#'   (see the examples section below).
-#'   \item \code{seed} The seed for random number generation to make results
-#'   reproducible. If \code{NA} (the default), \pkg{Stan} will set the seed
-#'   randomly.
-#'   \item \code{refresh} (non-negative integer) The number of iterations
-#'   between printed screen updates. If `refresh = 0`, only error messages
-#'   will be printed.
-#'   \item \code{silent} Logical; If \code{TRUE} (the default), most of the
-#'   informational messages of compiler and sampler are suppressed. The actual
-#'   sampling progress is still printed. Set \code{refresh = 0} to turn this off
-#'   as well. If using \code{backend = "rstan"} you can also set
-#'   \code{open_progress = FALSE} to prevent opening additional progress bars.
-#' }
-#' These arguments are converted to their specific names at the
+#'  \pkg{Stan} via \pkg{brms} package in R.
+#'
+#'  The arguments are converted to their specific names at the
 #'  time that the model is fit. Other options and argument can be
 #'  set using `set_engine()`. If left to their defaults
 #'  here (`NULL`), the values are taken from the underlying model
-#'  functions. If parameters need to be modified, `update()` can be used
-#'  in lieu of recreating the object from scratch.
+#'  functions. If parameters need to be modified, `update()` can be
+#'  used in lieu of recreating the object from scratch.
 #'
 #' @param mode A single character string for the type of model.
 #'  Possible values for this model are "unknown", "regression", or
 #'  "classification".
-#' @param prior One or more \code{brmsprior} objects created by
-#'   \code{\link[brms]{set_prior}} or related functions and combined using the
-#'   \code{c} method or the \code{+} operator.
-#'   See also \code{\link[brms]{get_prior}} for more help.
-#' @param inits Either \code{"random"} or \code{"0"}. If inits is
-#'   \code{"random"} (the default), \pkg{Stan} will randomly generate initial
-#'   values for parameters. If it is \code{"0"}, all parameters are initialized
-#'   to zero. This option is sometimes useful for certain families, as it happens
-#'   that default (\code{"random"}) inits cause samples to be essentially
-#'   constant. Generally, setting \code{inits = "0"} is worth a try, if chains
-#'   do not behave well. Alternatively, \code{inits} can be a list of lists
-#'   containing the initial values, or a function (or function name) generating
-#'   initial values. The latter options are mainly implemented for internal
-#'   testing but are available to users if necessary. If specifying initial
-#'   values using a list or a function then currently the parameter names must
-#'   correspond to the names used in the generated \pkg{Stan} code (not the names
-#'   used in \R). For more details on specifying initial values you can consult
-#'   the documentation of the selected \code{backend}.
-#' @param chains Number of Markov chains (defaults to 4).
-#' @param iter Number of total iterations per chain (including warmup; defaults
-#'   to 2000).
-#' @param warmup A positive integer specifying number of warmup (aka burnin)
-#'   iterations. This also specifies the number of iterations used for stepsize
-#'   adaptation, so warmup samples should not be used for inference. The number
-#'   of warmup should not be larger than \code{iter} and the default is
-#'   \code{iter/2}.
-#' @param thin Thinning rate. Must be a positive integer. Set \code{thin > 1} to
-#'   save memory and computation time if \code{iter} is large.
-#' @param cores Number of cores to use when executing the chains in parallel,
-#'   which defaults to 1 but we recommend setting the \code{mc.cores} option to
-#'   be as many processors as the hardware and RAM allow (up to the number of
-#'   chains). For non-Windows OS in non-interactive \R sessions, forking is used
-#'   instead of PSOCK clusters.
-#' @param algorithm Character string naming the estimation approach to use.
-#'   Options are \code{"sampling"} for MCMC (the default), \code{"meanfield"}
-#'   for variational inference with independent normal distributions,
-#'   \code{"fullrank"} for variational inference with a multivariate normal
-#'   distribution, or \code{"fixed_param"} for sampling from fixed parameter
-#'   values. Can be set globally for the current \R session via the
-#'   \code{"brms.algorithm"} option (see \code{\link{options}}).
-#' @param backend Character string naming the package to use as the backend for
-#'   fitting the \pkg{Stan} model. Options are \code{"rstan"} (the default) or
-#'   \code{"cmdstanr"}. Can be set globally for the current \R session via the
-#'   \code{"brms.backend"} option (see \code{\link{options}}). Details on the
-#'   \pkg{rstan} and \pkg{cmdstanr} packages are available at
-#'   \url{https://mc-stan.org/rstan/} and \url{https://mc-stan.org/cmdstanr/},
-#'   respectively.
-#' @param control A named \code{list} of parameters to control the sampler's
-#'   behavior. It defaults to \code{NULL} so all the default values are used.
-#'   The most important control parameters are discussed in the 'Details'
-#'   section below. For a comprehensive overview see
-#'   \code{\link[rstan]{stan}}.
-#' @param future Logical; If \code{TRUE}, the \pkg{\link[future]{future}}
-#'   package is used for parallel execution of the chains and argument
-#'   \code{cores} will be ignored. Can be set globally for the current \R
-#'   session via the \code{future} option. The execution type is controlled via
-#'   \code{\link[future]{plan}} (see the examples section below).
-#' @param seed The seed for random number generation to make results
-#'   reproducible. If \code{NA} (the default), \pkg{Stan} will set the seed
-#'   randomly.
-#' @param refresh (non-negative integer) The number of iterations between
-#'   printed screen updates. If `refresh = 0`, only error messages will be
-#'   printed.
-#' @param silent Logical; If \code{TRUE} (the default), most of the
-#'   informational messages of compiler and sampler are suppressed. The actual
-#'   sampling progress is still printed. Set \code{refresh = 0} to turn this off
-#'   as well. If using \code{backend = "rstan"} you can also set
-#'   \code{open_progress = FALSE} to prevent opening additional progress bars.
+#'
+#' @param formula.override Overrides the formula; for details see
+#'  \code{\link[brms]{brmsformula}}.
+#'
+#' @inheritParams brms::brm
+#'
+#' @param stan_args A list of extra arguments to \pkg{Stan}.
 #'
 #' @details
 #' The data given to the function are not saved and are only used
@@ -200,34 +66,58 @@
 #' @export
 bayesian <-
   function(mode = "regression",
+           formula.override = NULL,
+           family = NULL,
            prior = NULL,
+           sample_prior = NULL,
+           knots = NULL,
+           stanvars = NULL,
+           fit = NULL,
            inits = NULL,
            chains = NULL,
            iter = NULL,
            warmup = NULL,
            thin = NULL,
            cores = NULL,
+           threads = NULL,
            algorithm = NULL,
            backend = NULL,
+           stan_args = NULL,
            control = NULL,
+           save_pars = NULL,
+           save_model = NULL,
+           file = NULL,
+           file_refit = NULL,
+           normalize = NULL,
            future = NULL,
            seed = NULL,
-           refresh = NULL,
            silent = NULL) {
     args <- list(
+      formula.override = rlang::enquo(formula.override),
+      family = rlang::enquo(family),
       prior = rlang::enquo(prior),
+      sample_prior = rlang::enquo(sample_prior),
+      knots = rlang::enquo(knots),
+      stanvars = rlang::enquo(stanvars),
+      fit = rlang::enquo(fit),
       inits = rlang::enquo(inits),
       chains = rlang::enquo(chains),
       iter = rlang::enquo(iter),
       warmup = rlang::enquo(warmup),
       thin = rlang::enquo(thin),
       cores = rlang::enquo(cores),
+      threads = rlang::enquo(threads),
       algorithm = rlang::enquo(algorithm),
       backend = rlang::enquo(backend),
+      stan_args = rlang::enquo(stan_args),
       control = rlang::enquo(control),
+      save_pars = rlang::enquo(save_pars),
+      save_model = rlang::enquo(save_model),
+      file = rlang::enquo(file),
+      file_refit = rlang::enquo(file_refit),
+      normalize = rlang::enquo(normalize),
       future = rlang::enquo(future),
       seed = rlang::enquo(seed),
-      refresh = rlang::enquo(refresh),
       silent = rlang::enquo(silent)
     )
 
@@ -291,19 +181,31 @@ translate.bayesian <- function(x, engine = x$engine, ...) {
 update.bayesian <-
   function(object,
            parameters = NULL,
+           formula.override = NULL,
+           family = NULL,
            prior = NULL,
+           sample_prior = NULL,
+           knots = NULL,
+           stanvars = NULL,
+           fit = NULL,
            inits = NULL,
            chains = NULL,
            iter = NULL,
            warmup = NULL,
            thin = NULL,
            cores = NULL,
+           threads = NULL,
            algorithm = NULL,
            backend = NULL,
+           stan_args = NULL,
            control = NULL,
+           save_pars = NULL,
+           save_model = NULL,
+           file = NULL,
+           file_refit = NULL,
+           normalize = NULL,
            future = NULL,
            seed = NULL,
-           refresh = NULL,
            silent = NULL,
            fresh = FALSE,
            ...) {
@@ -314,19 +216,31 @@ update.bayesian <-
     }
 
     args <- list(
+      formula.override = rlang::enquo(formula.override),
+      family = rlang::enquo(family),
       prior = rlang::enquo(prior),
+      sample_prior = rlang::enquo(sample_prior),
+      knots = rlang::enquo(knots),
+      stanvars = rlang::enquo(stanvars),
+      fit = rlang::enquo(fit),
       inits = rlang::enquo(inits),
       chains = rlang::enquo(chains),
       iter = rlang::enquo(iter),
       warmup = rlang::enquo(warmup),
       thin = rlang::enquo(thin),
       cores = rlang::enquo(cores),
+      threads = rlang::enquo(threads),
       algorithm = rlang::enquo(algorithm),
       backend = rlang::enquo(backend),
+      stan_args = rlang::enquo(stan_args),
       control = rlang::enquo(control),
+      save_pars = rlang::enquo(save_pars),
+      save_model = rlang::enquo(save_model),
+      file = rlang::enquo(file),
+      file_refit = rlang::enquo(file_refit),
+      normalize = rlang::enquo(normalize),
       future = rlang::enquo(future),
       seed = rlang::enquo(seed),
-      refresh = rlang::enquo(refresh),
       silent = rlang::enquo(silent)
     )
 
@@ -380,8 +294,6 @@ check_args.bayesian <- function(object) {
 
 #' Fit Bayesian models
 #' @inheritParams brms::brm
-#  @param formula.override Overrides the formula; for details see
-#    \code{\link[brms]{brmsformula}}.
 #  @param fit An instance of S3 class \code{brmsfit}; If \code{fit} is
 #     of class \code{brmsfit}, the fitted model will be updated using
 #     \code{\link[brms]{update.brmsfit}}.
@@ -422,6 +334,7 @@ check_args.bayesian <- function(object) {
 bayesian_fit <- function(formula, data, ...) {
   dots <- list(...)
 
+  # Override the formula, if needed
   if (inherits(
     dots$formula.override,
     c("brmsformula", "formula")
@@ -437,6 +350,11 @@ bayesian_fit <- function(formula, data, ...) {
   }
   dots$formula.override <- NULL
 
+  # Pass extra arguments to Stan
+  dots <- append(dots, dots$stan_args)
+  dots$stan_args <- NULL
+
+  # Fit or update the model
   if (brms::is.brmsfit(dots$fit)) {
     dots$object <- dots$fit
     dots$fit <- NULL
