@@ -19,6 +19,249 @@ bayesian_make <- function(modes = c("classification", "regression")) {
     parsnip::set_dependency("bayesian", "brms", "brms")
     parsnip::set_dependency("bayesian", "brms", "bayesian")
 
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "mode",
+      original = "mode",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "formula.override",
+      original = "formula.override",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "family",
+      original = "family",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "prior",
+      original = "prior",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "sample_prior",
+      original = "sample_prior",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "knots",
+      original = "knots",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "stanvars",
+      original = "stanvars",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "fit",
+      original = "fit",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "inits",
+      original = "inits",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "chains",
+      original = "chains",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "iter",
+      original = "iter",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "warmup",
+      original = "warmup",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "thin",
+      original = "thin",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "cores",
+      original = "cores",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "threads",
+      original = "threads",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "algorithm",
+      original = "algorithm",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "backend",
+      original = "backend",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "stan_args",
+      original = "stan_args",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "control",
+      original = "control",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "save_pars",
+      original = "save_pars",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "save_model",
+      original = "save_model",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "file",
+      original = "file",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "file_refit",
+      original = "file_refit",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "normalize",
+      original = "normalize",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "future",
+      original = "future",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "seed",
+      original = "seed",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+      model = "bayesian",
+      eng = "brms",
+      parsnip = "silent",
+      original = "silent",
+      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      has_submodel = FALSE
+    )
+
     parsnip::set_fit(
       model = "bayesian",
       eng = "brms",
@@ -27,13 +270,7 @@ bayesian_make <- function(modes = c("classification", "regression")) {
         interface = "formula",
         protect = c("formula", "data"),
         func = c(pkg = "bayesian", fun = "bayesian_fit"),
-        defaults = list(
-          family = if (mode == "classification") {
-            rlang::expr(brms::brmsfamily("binomial"))
-          } else {
-            rlang::expr(brms::brmsfamily("gaussian"))
-          }
-        )
+        defaults = list()
       )
     )
 
@@ -75,12 +312,11 @@ bayesian_make <- function(modes = c("classification", "regression")) {
             unname(results)
           },
           func = c(pkg = "bayesian", fun = "bayesian_predict"),
-          args =
-            list(
-              object = rlang::expr(object$fit),
-              newdata = rlang::expr(new_data),
-              summary = TRUE
-            )
+          args = list(
+            object = rlang::expr(object$fit),
+            newdata = rlang::expr(new_data),
+            summary = TRUE
+          )
         )
       )
 
@@ -109,12 +345,11 @@ bayesian_make <- function(modes = c("classification", "regression")) {
             results
           },
           func = c(pkg = "bayesian", fun = "bayesian_predict"),
-          args =
-            list(
-              object = rlang::expr(object$fit),
-              newdata = rlang::expr(new_data),
-              summary = TRUE
-            )
+          args = list(
+            object = rlang::expr(object$fit),
+            newdata = rlang::expr(new_data),
+            summary = TRUE
+          )
         )
       )
     } else {
@@ -149,17 +384,15 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           if (mode == "classification") {
             res_2 <-
               tibble::tibble(
-                lo =
-                  parsnip::convert_stan_interval(
-                    results,
-                    level = object$spec$method$pred$conf_int$extras$level
-                  ),
-                hi =
-                  parsnip::convert_stan_interval(
-                    results,
-                    level = object$spec$method$pred$conf_int$extras$level,
-                    lower = FALSE
-                  ),
+                lo = parsnip::convert_stan_interval(
+                  results,
+                  level = object$spec$method$pred$conf_int$extras$level
+                ),
+                hi = parsnip::convert_stan_interval(
+                  results,
+                  level = object$spec$method$pred$conf_int$extras$level,
+                  lower = FALSE
+                ),
               )
             res_1 <- res_2
             res_1$lo <- 1 - res_2$hi
@@ -171,17 +404,15 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           } else {
             res <-
               tibble::tibble(
-                .pred_lower =
-                  parsnip::convert_stan_interval(
-                    results,
-                    level = object$spec$method$pred$conf_int$extras$level
-                  ),
-                .pred_upper =
-                  parsnip::convert_stan_interval(
-                    results,
-                    level = object$spec$method$pred$conf_int$extras$level,
-                    lower = FALSE
-                  ),
+                .pred_lower = parsnip::convert_stan_interval(
+                  results,
+                  level = object$spec$method$pred$conf_int$extras$level
+                ),
+                .pred_upper = parsnip::convert_stan_interval(
+                  results,
+                  level = object$spec$method$pred$conf_int$extras$level,
+                  lower = FALSE
+                ),
               )
           }
           if (object$spec$method$pred$conf_int$extras$std_error) {
@@ -190,12 +421,11 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           res
         },
         func = c(pkg = "bayesian", fun = "bayesian_predict"),
-        args =
-          list(
-            object = rlang::expr(object$fit),
-            newdata = rlang::expr(new_data),
-            summary = FALSE
-          )
+        args = list(
+          object = rlang::expr(object$fit),
+          newdata = rlang::expr(new_data),
+          summary = FALSE
+        )
       )
     )
 
@@ -210,17 +440,15 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           if (mode == "classification") {
             res_2 <-
               tibble::tibble(
-                lo =
-                  parsnip::convert_stan_interval(
-                    results,
-                    level = object$spec$method$pred$pred_int$extras$level
-                  ),
-                hi =
-                  parsnip::convert_stan_interval(
-                    results,
-                    level = object$spec$method$pred$pred_int$extras$level,
-                    lower = FALSE
-                  ),
+                lo = parsnip::convert_stan_interval(
+                  results,
+                  level = object$spec$method$pred$pred_int$extras$level
+                ),
+                hi = parsnip::convert_stan_interval(
+                  results,
+                  level = object$spec$method$pred$pred_int$extras$level,
+                  lower = FALSE
+                ),
               )
             res_1 <- res_2
             res_1$lo <- 1 - res_2$hi
@@ -232,17 +460,15 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           } else {
             res <-
               tibble::tibble(
-                .pred_lower =
-                  parsnip::convert_stan_interval(
-                    results,
-                    level = object$spec$method$pred$pred_int$extras$level
-                  ),
-                .pred_upper =
-                  parsnip::convert_stan_interval(
-                    results,
-                    level = object$spec$method$pred$pred_int$extras$level,
-                    lower = FALSE
-                  ),
+                .pred_lower = parsnip::convert_stan_interval(
+                  results,
+                  level = object$spec$method$pred$pred_int$extras$level
+                ),
+                .pred_upper = parsnip::convert_stan_interval(
+                  results,
+                  level = object$spec$method$pred$pred_int$extras$level,
+                  lower = FALSE
+                ),
               )
           }
           if (object$spec$method$pred$pred_int$extras$std_error) {
@@ -251,12 +477,11 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           res
         },
         func = c(pkg = "bayesian", fun = "bayesian_predict"),
-        args =
-          list(
-            object = rlang::expr(object$fit),
-            newdata = rlang::expr(new_data),
-            summary = FALSE
-          )
+        args = list(
+          object = rlang::expr(object$fit),
+          newdata = rlang::expr(new_data),
+          summary = FALSE
+        )
       )
     )
 
@@ -269,12 +494,11 @@ bayesian_make <- function(modes = c("classification", "regression")) {
         pre = NULL,
         post = NULL,
         func = c(pkg = "bayesian", fun = "bayesian_predict"),
-        args =
-          list(
-            object = rlang::expr(object$fit),
-            newdata = rlang::expr(new_data),
-            summary = FALSE
-          )
+        args = list(
+          object = rlang::expr(object$fit),
+          newdata = rlang::expr(new_data),
+          summary = FALSE
+        )
       )
     )
 
@@ -289,12 +513,11 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           tibble::as_tibble(results)
         },
         func = c(pkg = "bayesian", fun = "bayesian_predict"),
-        args =
-          list(
-            object = rlang::expr(object$fit),
-            newdata = rlang::expr(new_data),
-            summary = TRUE
-          )
+        args = list(
+          object = rlang::expr(object$fit),
+          newdata = rlang::expr(new_data),
+          summary = TRUE
+        )
       )
     )
   }
